@@ -13,7 +13,7 @@
 #' classified as events, below which survival probabilities are classified, and
 #' at which expected values are rounded for integer outcomes.
 #' @param times numeric vector of follow-up times at which to predict
-#' survival events.
+#' survival events/probabilities.
 #' @param ... arguments passed to model-specific prediction functions.
 #' 
 #' @seealso \code{\link{fit}}, \code{\link{confusion}},
@@ -28,16 +28,16 @@
 #'               data = Melanoma, model = GBMModel)
 #' predict(gbmfit, newdata = Melanoma, times = 365 * c(2, 5, 10), type = "prob")
 #' 
-predict.MLModelFit <- function(object, newdata = NULL,
+predict.MLModelFit <- function(object, newdata = NULL, times = numeric(),
                                type = c("response", "prob"), cutoff = 0.5,
-                               times = numeric(), ...) {
+                               ...) {
   newdata <- preprocess(fitbit(object, "x"), newdata)
   requireModelNamespaces(fitbit(object, "packages"))
   obs <- response(object)
   pred <- fitbit(object, "predict")(unMLModelFit(object), newdata,
                                     fitbits = field(object, "fitbits"),
                                     times = times, ...)
-  pred <- convert_dim(obs, pred)
+  pred <- convert_prob(obs, pred, times = times)
   if (match.arg(type) == "response") {
     pred <- convert_response(obs, pred, cutoff = cutoff)
   }
